@@ -22,3 +22,5 @@ class KerasScaffoldDefinition(WrittenModelScaffoldDefinition):
 
     def serialize_model_to_directory(self, model_directory):
         self.model.save(model_directory)
+        if self.python_major_minor:
+            self._build_args['PYVERSION'] = self.python_major_minor
