@@ -1,4 +1,5 @@
 import ast
+import glob
 import pathlib
 from typing import Any, List, Dict
 
@@ -26,8 +27,14 @@ def _serialize_pytorch_model(model: Any, path_to_weight_file: str, model_files:
 
     has_supplied_model_class_definition = False
     model_files_dict = {'files': {}, 'model_class': class_name}
+    python_files = [f for f in model_files if f.endswith('.py') and pathlib.Path(f).exists()]
+    for item in model_files:
+        # Get all python files in directories
+        if pathlib.Path(item).is_dir():
+            python_files += glob.glob(f'{item}/**/*.py', recursive=True)
+    python_files = list(set(python_files))
 
-    for filepath in model_files:
+    for filepath in python_files:
         with open(filepath, 'r') as _file:
             file_contents = _file.read()
             model_files_dict['files'][filepath] = file_contents
