@@ -1,7 +1,9 @@
+import inspect
 import os
 import pathlib
 import sys
-from typing import Any
+from ast import ClassDef, FunctionDef
+from typing import Any, Dict, List, Tuple
 
 import pkg_resources
 from dataclasses import dataclass
@@ -159,3 +161,56 @@ def parse_requirements_file(requirements_file: str) -> dict:
                 pass
 
     return name_to_req_str
+
+
+def infer_model_init_parameters(model_class: Any) -> Tuple[List, List]:
+    full_arg_spec = inspect.getfullargspec(model_class.__init__)
+    named_args = full_arg_spec.args[1:]
+    number_of_kwargs = full_arg_spec.defaults and len(full_arg_spec.defaults) or 0
+    required_args = full_arg_spec.args[1:-number_of_kwargs]
+    return named_args, required_args
+
+
+def infer_model_init_parameters_ast(model_class_def: ClassDef) -> Tuple[List, List]:
+    named_args = []
+    required_args = []
+    init_model_functions = [node for node in model_class_def.body if isinstance(node, FunctionDef) and node.name == '__init__']
+
+    if not init_model_functions:
+        return named_args, required_args
+
+    assert len(init_model_functions) == 1, 'There should only be one __init__ function in the model class'
+    init_model_function = init_model_functions[0]
+    named_args = [arg.arg for arg in init_model_function.args.args][1:]
+    number_of_defaults = len(init_model_function.args.defaults)
+    required_args = named_args[:-number_of_defaults]
+    return named_args, required_args
+
+
+def validate_provided_parameters_with_model(model_class: Any, provided_parameters: Dict[str, Any]) -> None:
+    """
+    Validates that all provided parameters match the signature of the model.
+
+    Args:
+        model_class: The model class to validate against
+        provided_parameters: The parameters to validate
+    """
+    if type(model_class) == ClassDef:
+        named_args, required_args = infer_model_init_parameters_ast(model_class)
+    else:
+        named_args, required_args = infer_model_init_parameters(model_class)
+
+    # Check that there are no extra parameters
+    if not named_args:
+        return
+
+    if provided_parameters and type(provided_parameters) is not dict:
+        raise TypeError(f'Provided parameters must be a dict, not {type(provided_parameters)}')
+
+    for arg in provided_parameters:
+        if arg not in named_args:
+            raise ValueError(f'Provided parameter {arg} is not a valid init parameter for the model.')
+
+    for arg in required_args:
+        if arg not in provided_parameters:
+            raise ValueError(f'Required init parameter {arg} was not provided for this model.')
