@@ -4,7 +4,7 @@ from common.lib_support import ensure_sentry_sdk_installed
 def do_sentry_init():
     SENTRY_URL = os.environ.get('SENTRY_URL', '')
     RUNTIME_ENV = os.environ.get('RUNTIME_ENV', '')
-    if SENTRY_URL is not '':
+    if SENTRY_URL != '':
         ensure_sentry_sdk_installed()
         import sentry_sdk
         from sentry_sdk import set_tag
