@@ -39,7 +39,7 @@ class TransformerModel(kfserving.KFModel):
 
     def predict(self, request: Dict) -> Dict:
         response = {}
-        instances = request['instances']
+        instances = request['inputs']
         try:
             with torch.no_grad():
                 if self._has_named_args:
