@@ -35,8 +35,8 @@ class KerasModel(kfserving.KFModel):
     def predict(self, request: Dict) -> Dict:
         response = {}
         try:
-            instances = request['instances']
-            inputs = np.array(instances)
+            inputs = request['inputs']
+            inputs = np.array(inputs)
             result = self._model.predict(inputs).tolist()
             response['predictions'] = result
             return response
