@@ -45,7 +45,7 @@ class SKLearnModel(kfserving.KFModel):
     def predict(self, request: Dict) -> Dict[str, List]:
         response = {}
         try:
-            inputs = request['instances']
+            inputs = request['inputs']
             result = self._model.predict(inputs)
             response['predictions'] = result
             if self._model_supports_predict_proba:
